function [res resa pairs connectivity] = loop_monte_carlo(m, ns, ndiscard, metric)

% Generate Figure 7.3 quantile plots from different data sets.
%m = 2000;   % number of simulations
%ns = 10000; % number of sample points
%ndiscard = 9500;

nd = ns + ndiscard;
% Perform m Monte Carlo simulations
[res, resa] = loop_asymp_monte_carlo(m, ns, ndiscard, metric);

headTitle = ['Figure 7.3 iPDC x3-->x2 and x2-->x3, m = ' int2str(m) ', ns = ' int2str(ns)]
pairs = [[2,3]; [3,2]];

connectivity = [0 1]; % 0 = not connected; 1 = connected.
qqplots(res, resa,  metric, pairs, connectivity, headTitle);

% print('-depsc2','-adobecset', ['loop_asymp_qqplots_' int2str(ns) '_' int2str(ndiscard) '.eps'])
% print('-dpdf','-adobecset',['loop_asymp_qqplots_' int2str(ns) '_' int2str(ndiscard) '.pdf'])
% hgsave(['loop_asymp_qqplots_' int2str(ns) '_' int2str(ndiscard)])

%=========================================================================

function [res, resa] = loop_asymp_monte_carlo(m, ns, ndiscard, metric)
%Perform Monte Carlo simulation.
%
%function [res, resa] = phil_monte_carlo(m = 10000, ns = 20000, ndiscard = 2000)
%
% input: m - number of simulation
%        ns - analyzed data length
%        ndiscard - initial discarded points
%
% output:  res       - results used by qqplots.m
%          resa      -

if nargin == 0,
    m  = 2000
    ns = 2000
    ndiscard = 2000;
    metric = 'diag'
end;
global pr_

pr_.metric = metric   % Asymptotic statistics metric
pr_.fixp = 1;         % True
pr_.maxp = 3;  IP = 2;% max IP
pr_.ss = 0;           % False
pr_.nf =128;           % Number of frequency points.
% if vector presented at those points LAB26/11/2012
pr_.v = 0;            % False

n = 3;                % Number of variables?

if nargin < 3,
    ndiscard = 200;
end;
[Ao, eo] = model2([]);

sumA = 0;
sume = 0;

res = zeros(m,n,n,pr_.nf);
for i = 1:m,        % m simulations
    if mod(i,100) == 0,
        fprintf('iter %4.0f\n', i);
    end;

    % Generate data sample.
    data = ar_loop_asymp(Ao, eo, ns, ndiscard); % Ao & eo are truth values
                                                % of the VAR model
    % MVAR estimation:
    [du,e,A,pb,B,ef,eb,vaic,Vaicv] = mvar(data,IP,1,5);
    %    alg=1;       Nutall-Strand---------------^ ^
    %    criterion=5; Fixed IP----------------------|
    %    maxIP = IP;  IP value itself
    res(i,:,:,:) = abs(pdc_alg_A(A, e, pr_.nf,pr_.metric)).^2;

    sumA = sumA + A;
    sume = sume + e;

    pr_.v = 0; %False;
end;

% Average A & e
Am = sumA/m;
em = sume/m;

resa = zeros(4,n,n,pr_.nf);

data = ar_loop_asymp(Ao, eo, ns, ndiscard);
alpha = 0.05;

c = asymp_pdc(data, Am, em, pr_.nf, pr_.metric, alpha);

resa(1,:,:,:) = c.pdc;            % pdc
resa(2,:,:,:) = sqrt(c.varass1);  % r[1] == th
resa(3,:,:,:) = c.patden*ns;      % r[6] == patden
resa(4,:,:,:) = c.patdf;          % r[5] == patdf

%==========================================================================
function [A,e]= model2(dummy)
% Adapted from Baccala & Sameshima 2001
e =[1 5 .30; 5 100 2; .30 2 1];
A = zeros(3,3,2);
A(:,:,1) = [.95*sqrt(2) 0 .35; .5 .5 0; 0 1 -.5];
A(1,1,2) = -.9025;

function c = ar_loop_asymp(A, er, ns, ndiscard)
% function c = ar_data(A, er, ns, ndiscard)
%    Simulate ar-model from A matrix
%
%       Input:
%         A(n, n, p) - AR model (n - number of signals, p - model order)
%         er(n) - variance of innovations
%         ns - length of simulated time-series
%
%       Output:
%         data(n, ns) - simulated time-series
%

if ndims(A) == 2,
    [n,du]=size(A);
    p=1;
elseif ndims(A) == 3,
    [n du p] = size(A);
else
    error('A matrix dimension > 3.');
end;

nd = ns + ndiscard;

SZ=[1 5 .30; 5 100 2; .30 2 1]; SZ1=chol(SZ);

wi = randn(3,nd); wi = SZ1'*wi;
x1 = zeros(1,nd); x2 = zeros(1,nd); x3 = zeros(1,nd);

% Variables initialization
for t=1:2,
    x1(t) = randn(1); x2(t) = randn(1); x3(t) = randn(1);
end;

chLabels = []; % or
%chLabels = {'x_1';'x_2';'x_3'};

for t=3:nd,
    x1(t) = 0.95*sqrt(2)*x1(t-1) - 0.9025*x1(t-2) + 0.35*x3(t-1) +  wi(1,t);
    x2(t) = .5*x1(t-1) + .5*x2(t-1) + wi(2,t);
    x3(t) = -.5*x3(t-1) + x2(t-1) + wi(3,t);
end;

y = [x1' x2' x3']; % data must be organized column-wise
c = y(nd-ns+1:nd,:)';
