% Eichler. On the evaluation of information flow in multivariate systems 
% by the directed transfer function.
%            Biol Cybern (2006) 94: 469?482
%           [http://dx.plos.org/10.1007/s00422-006-0062-z] 
% 
%  Example - two-dimensional VAR[2].

clc; format compact
N=60000;
disp('======================================================================');
disp('                   Three dimensional linear VAR[2] Model')
disp('                           Eichler, 2006.')
disp('                               x1-->x2');
disp('======================================================================');

if ~exist('flgManual','var')
   flgManual = 0
end;

if flgManual
   if exist('randn_manual_state.mat','file'),
      load randn_manual_state
      randn('state', s);
      disp(['Using state saved in "randn_manual_state.mat" to reproduce figure in the manual.']);
   else
      disp(['Did not find "randn_manual_state.mat" file.' ...
         'Assigned "sum(100*clock)" initial state.']);
      randn('state', sum(100*clock))
   end;
else
%   randn('state', sum(100*clock))
   randn('state', 100*acos(-1))
   disp('Assigned "sum(100*clock)" initial state.2')
end;
% Variables initialization
e=randn(2,N);
x1=zeros(1,N);
x2=zeros(1,N);

disp('======================================================================');

for t=1:4,
   x1(t)=randn(1); x2(t)=randn(1);
end;

chLabels = {'x_1';'x_2'}; %or %chLabels = []; 

for t=5:N,
   x1(t) = 7/8*x1(t-1) - 4/5*x1(t-2) +4/5*x1(t-3) - 1/2*x1(t-4) + e(1,t);
   x2(t) = 1/20*x1(t-1) + 1/20*x1(t-2) + e(2,t);

end;


nDiscard=5000;  % number of points discarded at beginning of series
nPoints=1000;   % number of analyzed samples points

y=[x1' x2']; % data must be organized column-wise
u=y(nDiscard+1:nDiscard+nPoints,:);

[nSegLength,nChannels]=size(u);

%==========================================================================
%             original PDC estimation and analysis parameters
%==========================================================================

run example_analysis_parameters % Setting default paramaters 
flgStandardize = 0
run example_pre_processing      % Detrending and/or standardization

run example_mvar_estimation     % Estimating VAR and testing adequacy of 
                                % VAR model as well as performing GCT and ICT.
criterion = 1;
maxIP = 4;
%=======Overriding some default parameters for plotting and analysis=======

metric = 'euc';
flgColor = 1;

run example_pdc_analysis        % Estimate PDC and asymptotic statistics

%========================PDCn Matrix Layout Plotting=======================
w_max=fs/2;
for kflgColor = flgColor,
   h=figure;
   set(h,'NumberTitle','off','MenuBar','none', ...
      'Name', 'Eichler(2006) Linear model')
   [hxlabel hylabel] = pdc_xplot(c,...
      flgPrinting,fs,w_max,chLabels,kflgColor);
   pdc_xplot_title(alpha,metric);
end;

%==========================================================================
%       gPDC analysis of Guo et al (2008) Common exogenous noise model
%==========================================================================

%=======Overriding some default parameters for plotting and analysis=======
flgPrinting = [1 1 1 0 0 0 1]; % overriding default setting
metric = 'diag';
flgColor = [1];

run example_pdc_analysis

%========================gPDC Matrix Layout Plotting=======================

w_max=fs/2;
for kflgColor = flgColor,
   h=figure;
   set(h,'NumberTitle','off','MenuBar','none', ...
      'Name', 'Eichler(2006) Linear model')
   [hxlabel hylabel] = pdc_xplot(c,...
      flgPrinting,fs,w_max,chLabels,kflgColor);
   pdc_xplot_title(alpha,metric);
end;

%==========================================================================
%                     iPDC analysis of the same process
%==========================================================================

%====Overriding default some parameters value for plotting andanalysis=====

flgPrinting = [1 1 1 0 0 0 1]; % overriding default setting

metric = 'info';
flgColor = [1];
alpha = 0.05;
run example_pdc_analysis


%========================iPDC Matrix Layout Plotting=======================
w_max=fs/2;
for kflgColor = flgColor,
   h=figure;
   set(h,'NumberTitle','off','MenuBar','none', ...
      'Name', 'Eichler(2006) Linear model')
   [hxlabel hylabel] = xplot(c,...
      flgPrinting,fs,w_max,chLabels,kflgColor);
   xplot_title(alpha,metric);
end;

% disp('==> Guo et al. (2008)''s five-dimensional VAR[3] process with large')
% disp('    common exogenous inputs, a modified version of a example ')
% disp('    from Baccal & Sameshima (2001). The exogenous inputs')
% disp('    introduce large common variance that overpower the magnitude of')
% disp('    directed interactions. As you may have noticed, there are')
% disp('    significant instantaneous Granger causality between all pair of')
% disp('    variables.')
% disp('    Due to large common exogenous white noise probably one may see ')
% disp('    false-positive and false-negative connectivity in some ')
% disp('    simulations, which will depend on your choice of alpha.')
% disp('    ')
% disp('==> The PDC and gPDC figures do not resemble PDC plot in Fig.1')
% disp('    in Guo et al. (2008). Our best guess is that Guo & colleagues')
% disp('    used an incorrect PDC estimator. Actually you may notice')
% disp('    that PDC and gPDC estimates are very similar to PGC ')
% disp('    in Guo et al (2008).')
% disp('==> In all three PDC formulations, the significant PDC frequency ') 
% disp('    range is similar. iPDC gives a measure of size effect, which is')
% disp('    very small in this case. Even so iPDC is significant in the same')
% disp('    frequency range as PDC and gPDC.')
% disp('==> In conclusion: the statement by Guo and collaborators that PDC can')
% disp('    not uncover the connectivity pattern in large common noise does')
% disp('    hold. For nonlinear systems, in some cases PDC and other linear')
% disp('    methods can uncover correct connectivity pattern, but in other')
% disp('    models PDC and GCT will simply fail.') 

disp(' ')
disp('======================================================================');
disp('             This completes Guo et al. (2008) example.');
disp('======================================================================');
